@@ -9,6 +9,7 @@ from .heater import GeckoWaterHeater
 from .keypad import GeckoKeypad
 from .light import GeckoLight
 from .pump import GeckoPump
+from .switches import GeckoSwitch
 from .sensors import GeckoSensor, GeckoBinarySensor
 from .watercare import GeckoWaterCare
 from ..driver import Observable
@@ -30,6 +31,7 @@ class GeckoFacade(Observable):
         self._water_heater = None
         self._water_care = None
         self._keypad = None
+        self._ecomode = None
         self._update_thread = threading.Thread(
             target=self._update_thread_func, daemon=True
         )
@@ -184,6 +186,18 @@ class GeckoFacade(Observable):
             if binary_sensor[1] in self._spa.accessors
         ]
 
+        if GeckoConstants.KEY_ECON_ACTIVE in self._spa.accessors:
+            self._ecomode = GeckoSwitch(
+                self,
+                GeckoConstants.KEY_ECON_ACTIVE,
+                (
+                    GeckoConstants.ECON_ACTIVE_DESCRIPTION,
+                    GeckoConstants.KEYPAD_ECOMODE,
+                    GeckoConstants.KEY_ECON_ACTIVE,
+                    GeckoConstants.DEVICE_CLASS_SWITCH,
+                ),
+            )
+
     @property
     def unique_id(self):
         """ A unique id for the facade """
@@ -244,6 +258,11 @@ class GeckoFacade(Observable):
         """ Get the binary sensor list """
         return self._binary_sensors
 
+    @property
+    def eco_mode(self):
+        """ Get the Eco Mode switch """
+        return self._ecomode
+
     @property
     def all_user_devices(self):
         """ Get all the user controllable devices as a list """
@@ -256,7 +275,7 @@ class GeckoFacade(Observable):
             self.all_user_devices
             + self.sensors
             + self.binary_sensors
-            + [self.water_heater, self.water_care, self.keypad]
+            + [self.water_heater, self.water_care, self.keypad, self.eco_mode]
         )
 
     def get_device(self, key):
