@@ -1,6 +1,7 @@
 """ GeckoShell class """
 
-import sys, traceback
+import sys
+import traceback
 import logging
 import datetime
 from .shared_command import GeckoCmd
@@ -136,7 +137,7 @@ class GeckoShell(GeckoCmd):
         print("Set pump {0} {1}".format(device.name, arg))
         try:
             device.set_mode(arg)
-        except Exception as e:
+        except Exception:
             traceback.print_exc()
 
     def do_state(self, arg):
@@ -157,6 +158,7 @@ class GeckoShell(GeckoCmd):
         print(self.facade.water_care)
         for sensor in [*self.facade.sensors, *self.facade.binary_sensors]:
             print(sensor)
+        print(self.facade.eco_mode)
 
     def monitor_get_states(self):
 
@@ -169,6 +171,7 @@ class GeckoShell(GeckoCmd):
             self.facade.water_care,
             *self.facade.sensors,
             *self.facade.binary_sensors,
+            self.facade.eco_mode,
         ]
 
         return [f"{state.monitor}" for state in states]
@@ -253,6 +256,14 @@ class GeckoShell(GeckoCmd):
         except Exception:  # pylint: disable=broad-except
             logger.exception("Exception getting '%s'", arg)
 
+    def do_peek(self, arg):
+        """Get the byte value from the structure at the specified position : peek <pos>"""
+        try:
+            pos = int(arg)
+            print(f"Byte at {pos} = {self.facade.spa.struct.status_block[pos]}")
+        except Exception:  # pylint: disable=broad-except
+            logger.exception("Exception peeking at '%s'", arg)
+
     def do_set(self, arg):
         """Set the value of the specified spa pack structure
         element : set <Element>=<value>"""
@@ -273,6 +284,13 @@ class GeckoShell(GeckoCmd):
         """Set the spa setpoint temperature : setpoint <temp>"""
         self.facade.water_heater.set_target_temperature(float(arg))
 
+    def do_eco(self, arg):
+        """Set the spa eco mode : eco on|off"""
+        if arg.lower() == "off":
+            self.facade.eco_mode.turn_off()
+        else:
+            self.facade.eco_mode.turn_on()
+
     def do_snapshot(self, arg):
         """Take a snapshot of the spa data structure with a descriptive
         message : SNAPSHOT <desc>"""
